import { defineStore } from "pinia";

export const useStore = defineStore({
  id: "counter",
  state: () => ({
    language: "fr-FR",
    theme: "",
  }),
  persist: {
    enabled: true,
  },
  actions: {
    switchLanguage() {
      this.language = this.language == "fr-FR" ? "en-US" : "fr-FR";
    },
    switchTheme() {
      if (this.theme == "") {
        this.theme = "dark";
        document.body.classList.remove("theme-light");
        document.body.classList.add("theme-dark");
      } else if (this.theme == "dark") {
        this.theme = "light";
        document.body.classList.remove("theme-dark");
        document.body.classList.add("theme-light");
      } else {
        this.theme = "";
        document.body.classList.remove("theme-light");
        document.body.classList.remove("theme-dark");
      }
    },
  },
});

export const useAuthStore = defineStore({
  id: "auth",
  state: () => ({
    // initialize state from local storage to enable user to stay logged in
    user: JSON.parse(localStorage.getItem("user")),
    returnUrl: null,
  }),
  actions: {
    async login(username, password) {
      const user = "test";

      // update pinia state
      this.user = user;

      // store user details and jwt in local storage to keep user logged in between page refreshes
      localStorage.setItem("user", JSON.stringify(user));

      // redirect to previous url or default to home page
      router.push(this.returnUrl || "/");
    },
    logout() {
      this.user = null;
      localStorage.removeItem("user");
      router.push("/login");
    },
  },
});
